@@ -2,7 +2,7 @@
 
 package Tapper::Schema::TestrunDB::Result::TestrunScheduling;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '5.0.6';
+$Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '5.0.7';
 # ABSTRACT: Tapper - Containing informations for an executed testrun
 
 use YAML::Syck;
@@ -43,8 +43,6 @@ sub mark_as_running
 {
         my ($self) = @_;
 
-        # set scheduling info
-        $self->status("running");
         # need a transaction because someone might access this
         # variable on the CLI
         my $guard = $self->result_source->schema->txn_scope_guard;
@@ -56,11 +54,12 @@ sub mark_as_running
         } else {
                 $self->host->free(0);
         }
-        $self->prioqueue_seq(undef);
-
-        # sync db
         $self->host->update;
+
+        $self->prioqueue_seq(undef);
+        $self->status("running");
         $self->update;
+
         $guard->commit;
 }
 
@@ -69,9 +68,6 @@ sub mark_as_finished
 {
         my ($self) = @_;
 
-        # set scheduling info
-        $self->status("finished");
-
         # need a transaction because someone might access this
         # variable on the CLI
         my $guard = $self->result_source->schema->txn_scope_guard;
@@ -83,11 +79,12 @@ sub mark_as_finished
                         $self->host->free(1);
                 }
         } else {
+            if ($self->host->testrunschedulings->search({status => "running"})->count == 1) { # mitigate scheduler bug where multiple jobs run on same host; this condition here hopefully recovers the situation.
                 $self->host->free(1);
+            }
         }
-
-        # sync db
         $self->host->update;
+        $self->status("finished");
         $self->update;
         $guard->commit;
 }
